==> haskell-safecopy-0.9.3.3-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safecopy
version: 0.9.3.3
id: safecopy-0.9.3.3-2q96rUPfJ537XersIpkRiv
key: safecopy-0.9.3.3-2q96rUPfJ537XersIpkRiv
license: PublicDomain
maintainer: Lemmih <lemmih@gmail.com>
homepage: https://github.com/acid-state/safecopy
synopsis: Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.
category: Data, Parsing
author: David Himmelstrup, Felipe Lessa
exposed: True
indefinite: False
exposed-modules:
    Data.SafeCopy Data.SafeCopy.Internal
hidden-modules: Data.SafeCopy.Instances Data.SafeCopy.SafeCopy
                Data.SafeCopy.Derive
abi: 708cbfe0a7bb86b7ee9ace53f413417e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/safecopy-0.9.3.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/safecopy-0.9.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/safecopy-0.9.3.3
hs-libraries: HSsafecopy-0.9.3.3-2q96rUPfJ537XersIpkRiv
depends:
    base-4.10.1.0 array-0.5.2.0 cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML
    bytestring-0.10.8.2 containers-0.5.10.2
    old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus template-haskell-2.12.0.0
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj time-1.8.0.2
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML=ed459ea038cbdb253abe2c011f65c556
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus=3a4f708e3a8313990a7ddaa44eed9995
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=d8375a46a4155c3f449ce3d319b3dbaa
haddock-interfaces: /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html: /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-safecopy-0.9.3.3-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-safecopy.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: safecopy
version: 0.9.3.3
id: safecopy-0.9.3.3-OyietDtTS71J3pucOj2S4
key: safecopy-0.9.3.3-OyietDtTS71J3pucOj2S4
license: PublicDomain
maintainer: Lemmih <lemmih@gmail.com>
homepage: https://github.com/acid-state/safecopy
synopsis: Binary serialization with version control.
description:
    An extension to Data.Serialize with built-in version control.
category: Data, Parsing
author: David Himmelstrup, Felipe Lessa
exposed: True
indefinite: False
exposed-modules:
    Data.SafeCopy Data.SafeCopy.Internal
hidden-modules: Data.SafeCopy.Instances Data.SafeCopy.SafeCopy
                Data.SafeCopy.Derive
abi: 072ce38e9452b812bda33d833c3afa79
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/safecopy-0.9.3.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/safecopy-0.9.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/safecopy-0.9.3.3
hs-libraries: HSsafecopy-0.9.3.3-OyietDtTS71J3pucOj2S4
depends:
    base-4.10.1.0 array-0.5.2.0 cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML
    bytestring-0.10.8.2 containers-0.5.10.2
    old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus template-haskell-2.12.0.0
    text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj time-1.8.0.2
    vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             cereal-0.5.4.0-HHG4trmDAey7tG5Rc3nyML=ed459ea038cbdb253abe2c011f65c556
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             old-time-1.1.0.3-46BMzRKZrT477y0C8mrrus=3a4f708e3a8313990a7ddaa44eed9995
             template-haskell-2.12.0.0=24d98a36b9e0dbd4d443161d478c05b2
             text-1.2.3.0-6107d52Rn3mLJ1xgqHMkbj=b7726d921cac66adc5c8f9f66f5b25f0
             time-1.8.0.2=d7392e85059cb108aeb68d6e24815970
             vector-0.12.0.1-JlawpRjIcMJIYPJVsWriIA=137c9db50bf637e10c6e6dd9e685ce59
haddock-interfaces: /usr/share/doc/haskell-safecopy/html/safecopy.haddock
haddock-html: /usr/share/doc/haskell-safecopy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
